pub fn parse_request(input: &str) -> Result<ParsedRequest, DslError>Expand description
Parse a request input string, returning either a single op or a batch.
pub fn parse_request(input: &str) -> Result<ParsedRequest, DslError>Parse a request input string, returning either a single op or a batch.